#!/usr/bin/env python

from mapies.generic import GenericDataStore
from pathlib import Path
from typing import List


obsid_DA = {
    'VIIRS': 34
}


def nc_DA(ds: GenericDataStore, dest: str | Path) -> List[Path]:
    """
    Write data to the netCDF4 format used by the DA
    :param ds: DataStore (normally any should work)
    :param dest: path where the files should be written
    :return:
    """
    outfiles = []

    # data are written in hourly netCDF4 files
    ds.data.loc[:, 'hour'] = ds.data.time.dt.strftime('%Y%m%d%H')
    for hour in ds.data.hour.unique():
        if ds.datatype == 'TotalColumn':
            filename = Path(dest) / f'obs{hour}.nc'
            df = ds.data.loc[ds.data.hour == hour]
            df.loc[:, ['obsid']] = obsid_DA[ds.instrument]
            df.loc[:, ['obstype']] = 30
            df.loc[:, ['obslev']] = -99999    # Ideally this should be handled by the DA directly
            df.loc[:, ['obsn']] = 1           # Normally this is no longer needed by the DA
            df.loc[:, ['obslon']] = df.rotated_lon.values
            df.loc[:, ['obslat']] = df.rotated_lat.values
            df.loc[:, ['obserr']] = df.err.values
            df.to_xarray().to_netcdf(filename, encoding={})
            outfiles.append(filename)
        else:
            raise NotImplementedError

    return outfiles
